@@ -20,17 +20,6 @@
 # @author Martijn Schuemie
 # @author Marc Suchard
 
-#' SqlRender
-#'
-#' @docType package
-#' @name SqlRender
-#' @importFrom utils install.packages menu
-NULL
-
-.onLoad <- function(libname, pkgname) {
-  rJava::.jpackage(pkgname, lib.loc = libname)
-}
-
 #' @title
 #' Render SQL code based on parameterized SQL and parameter values
 #'
